==> adms-2.2.7.tar.gz: adms-2.2.7/admsCheck/spectreMODULE_dc.ckt.xml.c <==
/* File automatically created by /cygdrive/d/Profiles/r29173/Projects/sf/adms/scripts/text2Ccode.pl*/

const char * spectreMODULE_dc_ckt_xml = ""
"<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n"
"\n"
"<!--\n"
"  $Id: spectreMODULE_dc.ckt.xml 635 2007-04-26 09:18:53Z r29173 $\n"
"  $Log$\n"
"  Revision 1.5  2006/08/04 17:15:32  r29173\n"
"  rearranged code partionning into files\n"
"\n"
"  Revision 1.4  2006/01/26 13:39:25  r29173\n"
"  fixed core dump when running admsCheck\n"
"\n"
"  Revision 1.16  2005/06/03 12:44:00  r29173\n"
"  update done by Cadence\n"
"\n"
"  Revision 1.14  2005/03/31 17:59:54  r29173\n"
"  migration to adms-2.x.x: converted to adms2 syntax\n"
"\n"
"  Revision 1.13  2005/02/28 08:08:26  r29173\n"
"  migration to adms-2.x.x: admst:version required\n"
"\n"
"  Revision 1.12  2005/02/26 23:54:35  r29173\n"
"  migration to adms-2.x.x: admst:if and admst:for-each use stricter syntax\n"
"\n"
"  Revision 1.11  2005/02/22 20:07:43  r29173\n"
"  migration to adms-2.x.x: renamed if:select to if:test\n"
"\n"
"  Revision 1.10  2005/02/20 11:45:37  r29173\n"
"  migration to adms-2.x.x: renamed device to module\n"
"\n"
"  Revision 1.9  2005/02/20 11:00:11  r29173\n"
"  migration to adms-2.x.x: renamed devicenode to node\n"
"\n"
"  Revision 1.8  2005/02/18 16:32:29  r29173\n"
"  migration to adms-2.x.x: changed syntax of admst:open\n"
"\n"
"  Revision 1.7  2005/02/08 13:37:14  r29173\n"
"  fixed most xmllint syntax errors\n"
"\n"
"  Revision 1.6  2005/02/01 08:59:37  r29173\n"
"  migration to adms-2.x.x - modified expression stringifier\n"
"\n"
"  Revision 1.5  2005/01/27 11:10:43  r29173\n"
"  migration to adms-2.x.x - fixed namespace (admst)\n"
"\n"
"  Revision 1.4  2004/11/26 14:21:15  r29173\n"
"  added package_string to all files\n"
"  added package_string to MODULE.c version\n"
"\n"
"  Revision 1.3  2004/10/18 14:01:20  r29173\n"
"  for adms release adms-1.33.0\n"
"  changed prefix of adms 'rules' from xsl: to adms:\n"
"  renamed 'adms rules' to 'adms transforms'\n"
"  renamed adms transforms adms:defined and adms:undefined to adms:if\n"
"  introduced SiMKiT to testbench\n"
"  improved handling of property 'separator' in adms:join\n"
"\n"
"  Revision 1.2  2004/10/08 18:41:20  r29173\n"
"  fixed bugs while improving xmlProgram.c\n"
"\n"
"  Revision 1.1.1.1  2004/05/21 13:04:20  r29173\n"
"  rebuild cvs data tree (crashed after revision 1_13_0!)\n"
"\n"
"  Revision 1.1.1.1  2004/03/22 12:14:31  r29173\n"
"  initial import\n"
"\n"
"  Revision 1.9  2004/03/22 11:50:18  r29173\n"
"  added more functions (cos, sin, ...)\n"
"\n"
"  Revision 1.8  2004/03/02 13:42:51  r29173\n"
"  sync. with adms-1.7.0\n"
"\n"
"  Revision 1.7  2004/02/25 10:33:34  r29173\n"
"  sync. with adms-1.7.0\n"
"\n"
"  Revision 1.6  2004/02/15 13:15:53  r29173\n"
"  sync with adms release 1.6.0\n"
"\n"
"  Revision 1.5  2003/10/08 13:25:07  r29173\n"
"  removed used of ../ where possible\n"
"\n"
"  Revision 1.3  2003/10/08 12:41:10  r29173\n"
"  removed used of /module/...\n"
"\n"
"  Revision 1.2  2003/10/08 12:13:50  r29173\n"
"  updated copyright - covers proprietary info of CMI interface\n"
"\n"
"-->\n"
"\n"
"<!--\n"
"     Written by Laurent Lemaitre - r29173@users.sourceforge.net\n"
"\n"
"     Documentation:\n"
"       http://sourceforge.net/docman/display_doc.php?docid=18993&group_id=84289\n"
"\n"
"     Target Interface: spectre446 or spectre50\n"
"     Supported by adms-1.x.x\n"
"\n"
"     This file covers proprietary information of the CMI\n"
"     interface of Spectre, a tool from Cadence Inc.\n"
"     Use and distribution of this file should be approved by\n"
"     legal representatives of Cadence Inc.\n"
"     support@cadence.com\n"
"\n"
"     This file is used by adms - http://sourceforge.net/projects/mot-adms.\n"
"\n"
"     adms is free software; you can redistribute it and/or modify\n"
"     it under the terms of the GNU General Public License as published by\n"
"     the Free Software Foundation; either version 2 of the License, or\n"
"     (at your option) any later version.\n"
"\n"
"     adms is distributed in the hope that it will be useful,\n"
"     but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
"     GNU General Public License for more details.\n"
"\n"
"     You should have received a copy of the GNU General Public License\n"
"     along with adms; if not, write to the Free Software\n"
"     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
"-->\n"
"\n"
"<!DOCTYPE admst SYSTEM \"admst.dtd\">\n"
"<admst version=\"2.2.0\" xmlns:admst=\"http://mot-adms.sourceforge.net/adms/admst.xml\">\n"
"\n"
"<admst:template match=\"number\">?number?</admst:template>\n"
"<admst:template match=\"mapply_unary\">?mapply_unary?</admst:template>\n"
"\n"
"<admst:for-each select=\"/module\">\n"
"<admst:message format=\" build file %(name)_dc.ckt\\n\"/>\n"
"<admst:value-of select=\"name\"/>\n"
"<admst:open file=\"%s_dc.ckt\">\n"
"<admst:value-of select=\"/simulator/package_string\"/>\n"
"<admst:text format=\"*** Interface: %s\\n\"/>\n"
"<admst:value-of select=\"/simulator/currentdate\"/>\n"
"<admst:value-of select=\"/simulator/fullname\"/>\n"
"<admst:text format=\"*** created by: %s - %s\\n\"/>\n"
"<admst:text format=\"\\n\"/>\n"
"\n"
"  <admst:value-of select=\"/simulator/currentdate\"/>\n"
"  <admst:text format=\"* Simple test circuit - automatically created %s \\n\" />\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:text format=\"simulator lang=spectre\\n\" />\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:text format=\"modelOptions options scale=1 gmin=1e-12 reltol=1.0e-8 vabstol=1.0e-08\\n\" />\n"
"  <admst:text format=\"setTnom alter param=tnom value=(27)\\n\" />\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:value-of select=\"name\"/>\n"
"  <admst:value-of select=\"name\"/>\n"
"  <admst:text format=\"model my%s %s\\n\" />\n"
"  <admst:for-each select=\"variable[scope='global_model']\">\n"
"    <admst:if test=\"[input='yes']\">\n"
"      <admst:choose>\n"
"        <admst:when test=\"attribute[name='spice:isflag' and value='yes']\">\n"
"        </admst:when>\n"
"        <admst:otherwise>\n"
"          <admst:value-of select=\"default/tree/adms/datatypename\"/>\n"
"          <admst:apply-templates select=\"default/tree\" match=\"%s\"/>\n"
"          <admst:value-of select=\"/simulator/tmp\"/>\n"
"          <admst:choose>\n"
"            <admst:when test=\"attribute[name='spice:name']\">\n"
"              <admst:for-each select=\"attribute[name='spice:name']\">\n"
"                <admst:value-of select=\"value\"/>\n"
"              </admst:for-each>\n"
"            </admst:when>\n"
"            <admst:otherwise>\n"
"              <admst:value-of select=\"name\"/>\n"
"            </admst:otherwise>\n"
"          </admst:choose>\n"
"          <admst:text format=\"+ %s = (%s)\\n\" />\n"
"        </admst:otherwise>\n"
"      </admst:choose>\n"
"    </admst:if>\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:value-of select=\"name\"/>\n"
"  <admst:text format=\"%s \" />\n"
"  <admst:for-each select=\"node[location='external']\">\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:text format=\"N_%s_%s_int \" />\n"
"  </admst:for-each>\n"
"  <admst:value-of select=\"name\"/>\n"
"  <admst:text format=\"my%s  \\n\" />\n"
"  <admst:for-each select=\"variable[scope='global_instance']\">\n"
"    <admst:if test=\"[input='yes']\">\n"
"      <admst:choose>\n"
"        <admst:when test=\"attribute[name='spice:isflag' and value='yes']\">\n"
"        </admst:when>\n"
"        <admst:otherwise>\n"
"          <admst:value-of select=\"default/tree/adms/datatypename\"/>\n"
"          <admst:apply-templates select=\"default/tree\" match=\"%s\"/>\n"
"          <admst:value-of select=\"/simulator/tmp\"/>\n"
"          <admst:choose>\n"
"            <admst:when test=\"attribute[name='spice:name']\">\n"
"              <admst:for-each select=\"attribute[name='spice:name']\">\n"
"                <admst:value-of select=\"value\"/>\n"
"              </admst:for-each>\n"
"            </admst:when>\n"
"            <admst:otherwise>\n"
"              <admst:value-of select=\"name\"/>\n"
"            </admst:otherwise>\n"
"          </admst:choose>\n"
"          <admst:text format=\"+ %s = (%s)\\n\" />\n"
"        </admst:otherwise>\n"
"      </admst:choose>\n"
"    </admst:if>\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:for-each select=\"node[location='external']\">\n"
"    <admst:text format=\"* inout node \\n\" />\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:text format=\"v_%s_%s_vdd N_%s_%s_vdd 0 vsource dc=1.0\\n\" />\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:text format=\"r_%s_%s1  N_%s_%s_int 0 resistor r=1.0\\n\" />\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:value-of select=\"name\"/>\n"
"    <admst:value-of select=\"module/name\"/>\n"
"    <admst:text format=\"r_%s_%s2  N_%s_%s_int N_%s_%s_vdd resistor r=1.0\\n\" />\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\" />\n"
"  <admst:text format=\"opPoint dc oppoint=screen print=yes\\n\" />\n"
"  <admst:text format=\"* infoall info what=all save=all\\n\" />\n"
"\n"
"</admst:open>\n"
"</admst:for-each>\n"
"\n"
"</admst>\n"
;

==> adms-2.2.8.tar.gz: adms-2.2.8/admsCheck/spectreMODULE_dc.ckt.xml.c <==
/* File automatically created by ../scripts/text2Ccode.pl*/

const char * spectreMODULE_dc_ckt_xml = ""
"<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n"
"\n"
"<!--\n"
"  $Id: spectreMODULE_dc.ckt.xml 701 2007-08-31 10:17:31Z r29173 $\n"
"  $Log$\n"
"  Revision 1.5  2006/08/04 17:15:32  r29173\n"
"  rearranged code partionning into files\n"
"\n"
"  Revision 1.4  2006/01/26 13:39:25  r29173\n"
"  fixed core dump when running admsCheck\n"
"\n"
"  Revision 1.16  2005/06/03 12:44:00  r29173\n"
"  update done by Cadence\n"
"\n"
"  Revision 1.14  2005/03/31 17:59:54  r29173\n"
"  migration to adms-2.x.x: converted to adms2 syntax\n"
"\n"
"  Revision 1.13  2005/02/28 08:08:26  r29173\n"
"  migration to adms-2.x.x: admst:version required\n"
"\n"
"  Revision 1.12  2005/02/26 23:54:35  r29173\n"
"  migration to adms-2.x.x: admst:if and admst:for-each use stricter syntax\n"
"\n"
"  Revision 1.11  2005/02/22 20:07:43  r29173\n"
"  migration to adms-2.x.x: renamed if:select to if:test\n"
"\n"
"  Revision 1.10  2005/02/20 11:45:37  r29173\n"
"  migration to adms-2.x.x: renamed device to module\n"
"\n"
"  Revision 1.9  2005/02/20 11:00:11  r29173\n"
"  migration to adms-2.x.x: renamed devicenode to node\n"
"\n"
"  Revision 1.8  2005/02/18 16:32:29  r29173\n"
"  migration to adms-2.x.x: changed syntax of admst:open\n"
"\n"
"  Revision 1.7  2005/02/08 13:37:14  r29173\n"
"  fixed most xmllint syntax errors\n"
"\n"
"  Revision 1.6  2005/02/01 08:59:37  r29173\n"
"  migration to adms-2.x.x - modified expression stringifier\n"
"\n"
"  Revision 1.5  2005/01/27 11:10:43  r29173\n"
"  migration to adms-2.x.x - fixed namespace (admst)\n"
"\n"
"  Revision 1.4  2004/11/26 14:21:15  r29173\n"
"  added package_string to all files\n"
"  added package_string to MODULE.c version\n"
"\n"
"  Revision 1.3  2004/10/18 14:01:20  r29173\n"
"  for adms release adms-1.33.0\n"
"  changed prefix of adms 'rules' from xsl: to adms:\n"
"  renamed 'adms rules' to 'adms transforms'\n"
"  renamed adms transforms adms:defined and adms:undefined to adms:if\n"
"  introduced SiMKiT to testbench\n"
"  improved handling of property 'separator' in adms:join\n"
"\n"
"  Revision 1.2  2004/10/08 18:41:20  r29173\n"
"  fixed bugs while improving xmlProgram.c\n"
"\n"
"  Revision 1.1.1.1  2004/05/21 13:04:20  r29173\n"
"  rebuild cvs data tree (crashed after revision 1_13_0!)\n"
"\n"
"  Revision 1.1.1.1  2004/03/22 12:14:31  r29173\n"
"  initial import\n"
"\n"
"  Revision 1.9  2004/03/22 11:50:18  r29173\n"
"  added more functions (cos, sin, ...)\n"
"\n"
"  Revision 1.8  2004/03/02 13:42:51  r29173\n"
"  sync. with adms-1.7.0\n"
"\n"
"  Revision 1.7  2004/02/25 10:33:34  r29173\n"
"  sync. with adms-1.7.0\n"
"\n"
"  Revision 1.6  2004/02/15 13:15:53  r29173\n"
"  sync with adms release 1.6.0\n"
"\n"
"  Revision 1.5  2003/10/08 13:25:07  r29173\n"
"  removed used of ../ where possible\n"
"\n"
"  Revision 1.3  2003/10/08 12:41:10  r29173\n"
"  removed used of /module/...\n"
"\n"
"  Revision 1.2  2003/10/08 12:13:50  r29173\n"
"  updated copyright - covers proprietary info of CMI interface\n"
"\n"
"-->\n"
"\n"
"<!--\n"
"     Written by Laurent Lemaitre - r29173@users.sourceforge.net\n"
"\n"
"     Documentation:\n"
"       http://sourceforge.net/docman/display_doc.php?docid=18993&group_id=84289\n"
"\n"
"     Target Interface: spectre446 or spectre50\n"
"     Supported by adms-1.x.x\n"
"\n"
"     This file covers proprietary information of the CMI\n"
"     interface of Spectre, a tool from Cadence Inc.\n"
"     Use and distribution of this file should be approved by\n"
"     legal representatives of Cadence Inc.\n"
"     support@cadence.com\n"
"\n"
"     This file is used by adms - http://sourceforge.net/projects/mot-adms.\n"
"\n"
"     adms is free software; you can redistribute it and/or modify\n"
"     it under the terms of the GNU General Public License as published by\n"
"     the Free Software Foundation; either version 2 of the License, or\n"
"     (at your option) any later version.\n"
"\n"
"     adms is distributed in the hope that it will be useful,\n"
"     but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
"     GNU General Public License for more details.\n"
"\n"
"     You should have received a copy of the GNU General Public License\n"
"     along with adms; if not, write to the Free Software\n"
"     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n"
"-->\n"
"\n"
"<!DOCTYPE admst SYSTEM \"admst.dtd\">\n"
"<admst version=\"2.2.8\" xmlns:admst=\"http://mot-adms.sourceforge.net/xml-files/admst\">\n"
"\n"
"<admst:template match=\"print_expression\">\n"
"  <admst:choose>\n"
"    <admst:when test=\"[datatypename='number']\">%(value)%(scalingunit)</admst:when>\n"
"    <admst:otherwise>-%(datatypename)-not-done-yet--</admst:otherwise>\n"
"  </admst:choose>\n"
"</admst:template>\n"
"\n"
"<admst:for-each select=\"/module\">\n"
"<admst:variable name=\"mname\" select=\"%(name)\"/>\n"
"<admst:message format=\"build file %(name)_dc.ckt\\n\"/>\n"
"<admst:open file=\"%(name)_dc.ckt\">\n"
"<admst:text format=\"*** Interface: %(/simulator/package_string)\\n\"/>\n"
"<admst:text format=\"*** created by: %(/simulator/fullname) - %(/simulator/currentdate)\\n\"/>\n"
"<admst:text format=\"\\n\"/>\n"
"\n"
"  <admst:text format=\"* Simple test circuit - automatically created %(/simulator/currentdate) \\n\"/>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:text format=\"simulator lang=spectre\\n\"/>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:text format=\"modelOptions options scale=1 gmin=1e-12 reltol=1.0e-8 vabstol=1.0e-08\\n\"/>\n"
"  <admst:text format=\"setTnom alter param=tnom value=(27)\\n\"/>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:text format=\"model my$mname $mname\\n\"/>\n"
"  <admst:for-each select=\"variable[scope='global_model']\">\n"
"    <admst:if test=\"[input='yes']\">\n"
"      <admst:choose>\n"
"        <admst:when test=\"attribute[name='spice:isflag' and value='yes']\">\n"
"        </admst:when>\n"
"        <admst:otherwise>\n"
"          <admst:choose>\n"
"            <admst:when test=\"attribute[name='spice:name']\">\n"
"              <admst:for-each select=\"attribute[name='spice:name']\">\n"
"                <admst:text format=\"+ %(value) = %(print_expression(default/tree))\\n\"/>\n"
"              </admst:for-each>\n"
"            </admst:when>\n"
"            <admst:otherwise>\n"
"              <admst:text format=\"+ %(name) = %(print_expression(default/tree))\\n\"/>\n"
"            </admst:otherwise>\n"
"          </admst:choose>\n"
"        </admst:otherwise>\n"
"      </admst:choose>\n"
"    </admst:if>\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:text format=\"$mname \"/>\n"
"  <admst:text select=\"node[location='external']\" format=\"N_$(mname)_%(name)_int \"/>\n"
"  <admst:text format=\"my$mname  \\n\"/>\n"
"  <admst:for-each select=\"variable[scope='global_instance']\">\n"
"    <admst:if test=\"[input='yes']\">\n"
"      <admst:choose>\n"
"        <admst:when test=\"attribute[name='spice:isflag' and value='yes']\">\n"
"        </admst:when>\n"
"        <admst:otherwise>\n"
"          <admst:choose>\n"
"            <admst:when test=\"attribute[name='spice:name']\">\n"
"              <admst:for-each select=\"attribute[name='spice:name']\">\n"
"                <admst:text format=\"+ %(value) = %(print_expression(default/tree))\\n\"/>\n"
"              </admst:for-each>\n"
"            </admst:when>\n"
"            <admst:otherwise>\n"
"              <admst:text format=\"+ %(name) = %(print_expression(default/tree))\\n\"/>\n"
"            </admst:otherwise>\n"
"          </admst:choose>\n"
"        </admst:otherwise>\n"
"      </admst:choose>\n"
"    </admst:if>\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:for-each select=\"node[location='external']\">\n"
"    <admst:text format=\"* inout node \\n\"/>\n"
"    <admst:text format=\"v_$(mname)_%(name)_vdd N_$(mname)_%(name)_vdd 0 vsource dc=1.0\\n\"/>\n"
"    <admst:text format=\"r_$(mname)_%(name)1  N_$(mname)_%(name)_int 0 resistor r=1.0\\n\"/>\n"
"    <admst:text format=\"r_$(mname)_%(name)2  N_$(mname)_%(name)_int N_$(mname)_%(name)_vdd resistor r=1.0\\n\"/>\n"
"  </admst:for-each>\n"
"  <admst:text format=\"\\n\"/>\n"
"  <admst:text format=\"opPoint dc oppoint=screen print=yes\\n\"/>\n"
"  <admst:text format=\"* infoall info what=all save=all\\n\"/>\n"
"\n"
"</admst:open>\n"
"</admst:for-each>\n"
"\n"
"</admst>\n"
;
